@@ -8,6 +8,7 @@ from .asserts import (  # noqa
 )
 from .exceptions import ImproperlyConfigured  # noqa
 from .expression_parser import ExpressionParser  # noqa
+from .expressions import Asterisk, row_to_json  # noqa
 from .functions import (  # noqa
     analyze,
     create_database,
@@ -27,6 +28,7 @@ from .functions import (  # noqa
     get_query_entities,
     get_referencing_foreign_keys,
     get_tables,
+    get_type,
     group_foreign_keys,
     has_changes,
     has_index,
@@ -60,6 +62,8 @@ from .types import (  # noqa
     Choice,
     ChoiceType,
     ColorType,
+    CompositeArray,
+    CompositeType,
     CountryType,
     CurrencyType,
     DateRangeType,
@@ -77,6 +81,8 @@ from .types import (  # noqa
     PasswordType,
     PhoneNumber,
     PhoneNumberType,
+    register_composites,
+    remove_composite_listeners,
     ScalarListException,
     ScalarListType,
     TimezoneType,
@@ -86,4 +92,4 @@ from .types import (  # noqa
     WeekDaysType
 )
 
-__version__ = '0.30.2'
+__version__ = '0.30.9'
