@@ -1,22 +1,9 @@
 import sqlalchemy as sa
-from sqlalchemy_utils import CountryType, Country
+
+from sqlalchemy_utils import Country, CountryType
 from tests import TestCase
 
 
-class TestCountry(object):
-    def test_init(self):
-        assert Country(u'fi') == Country(Country(u'fi'))
-
-    def test_equality_operator(self):
-        assert Country(u'fi') == u'fi'
-        assert u'fi' == Country(u'fi')
-        assert Country(u'fi') == Country(u'fi')
-
-    def test_non_equality_operator(self):
-        assert Country(u'fi') != u'sv'
-        assert not (Country(u'fi') != u'fi')
-
-
 class TestCountryType(TestCase):
     def create_models(self):
         class User(self.Base):
